m3e_bottom_sheet library

Material 3 Expressive (M3E) bottom sheet components for Flutter.

This library provides a Material 3 Expressive modal bottom sheet with spring physics entrance motion, drag handle, header layout, theming, and extensive customization options.

showM3EModalBottomSheet(
  context: context,
  builder: (context) => M3EBottomSheet(
    title: const Text('Theme Settings'),
    child: MyContent(),
  ),
);

Classes

M3EBottomSheet
Material 3 Expressive bottom sheet container widget.
M3EBottomSheetStyle
Style configuration for M3EBottomSheet and showM3EModalBottomSheet.
M3EBottomSheetTheme
An inherited widget that defines the visual properties for M3EBottomSheets in this widget's subtree.
M3EBottomSheetThemeData
Theme extension for configuring default styles of M3EBottomSheet.
M3EMotion
Spring animation configuration for Material 3 Expressive components.

Functions

showM3EModalBottomSheet<T>({required BuildContext context, required WidgetBuilder builder, Color? backgroundColor, String? barrierLabel, double? elevation, ShapeBorder? shape, Clip? clipBehavior, BoxConstraints? constraints, Color? barrierColor, bool isScrollControlled = true, double scrollControlDisabledMaxHeightRatio = 9.0 / 16.0, bool useRootNavigator = false, bool isDismissible = true, bool enableDrag = true, bool? showDragHandle, bool useSafeArea = true, RouteSettings? routeSettings, AnimationController? transitionAnimationController, Offset? anchorPoint, AnimationStyle? sheetAnimationStyle, M3EBottomSheetStyle? style, M3EMotion? motion}) Future<T?>
Shows a Material 3 Expressive modal bottom sheet with spring entrance motion.